# uteis
[![GitHub license](https://img.shields.io/github/license/Ran-n/uteis)](https://github.com/Ran-n/uteis/blob/master/LICENSE)

[Ran-n/uteis](https://github.com/Ran-n/uteis)

Paquete que consta dunha serie de ficheiros escritos
en python con funcións típicas e de gran uso.
Desta forma, en lugar de crear un ficheiro de uteis
para cada proxecto poderase engadir este módulo
e cargar as funcións precisas del no novo proxecto.

Exemplos de carga:  
> import uteis  
> from uteis import catex  
> from uteis import catex, ficheiro  
> from uteis import catex  
> from uteis.ficheiro import cargar  

## Doazóns
🙇🙇‍♀

Bitcoin  
bc1q79vja8jzr27dxaf3ylu7e49ady8zq0jsm5qfk6

Monero  
88Rezd6ZQzaCb1s7K1tRCiCaDzuHrfYsn4q348jJuePpLs84JNsWEghMAZZgzpDPrqD4PBxk7hwMkSdNQ4CLqFHyPVLdX1D

Wownero  
WW2RheTNrq8goAi42Dz5AKUj1qLSaTSSgiH7sHR2qRqojg238EXP3MM3xuUgswriET7UrpkEoYaCkecBhnU49oxM1dZyYoSmm
